@@ -35,6 +35,7 @@ import {
   bgFadeOut,
 } from '@/utils';
 import { tryNormalLogged } from '@/utils/guard';
+import { useCaptchaPlugin } from '@/utils/pluginKit';
 import {
   useQueryComments,
   addComment,
@@ -66,14 +67,14 @@ const Comment = ({ objectId, mode, commentId }) => {
   const reportModal = useReportModal();
 
   const addCaptcha = useCaptchaModal('comment');
-  const editCaptcha = useCaptchaModal('edit');
-  const dCaptcha = useCaptchaModal('delete');
-  const vCaptcha = useCaptchaModal('vote');
+  const editCaptcha = useCaptchaPlugin('edit');
+  const dCaptcha = useCaptchaPlugin('delete');
+  const vCaptcha = useCaptchaPlugin('vote');
 
   const { t } = useTranslation('translation', { keyPrefix: 'comment' });
 
   useEffect(() => {
-    if (pageIndex === 0 && commentId) {
+    if (pageIndex === 0 && commentId && comments.length !== 0) {
       setTimeout(() => {
         const el = document.getElementById(commentId);
         scrollToElementTop(el);
@@ -84,7 +85,7 @@ const Comment = ({ objectId, mode, commentId }) => {
     return () => {
       updateCurrentReplyId('');
     };
-  }, []);
+  }, [comments]);
 
   useEffect(() => {
     if (!data) {
@@ -136,6 +137,85 @@ const Comment = ({ objectId, mode, commentId }) => {
     );
   };
 
+  const submitUpdateComment = (params, item) => {
+    const up = {
+      ...params,
+      comment_id: item.comment_id,
+      captcha_code: undefined,
+      captcha_id: undefined,
+    };
+    editCaptcha?.resolveCaptchaReq(up);
+
+    return updateComment(up)
+      .then(async (res) => {
+        await editCaptcha?.close();
+        setComments(
+          comments.map((comment) => {
+            if (comment.comment_id === item.comment_id) {
+              comment.showEdit = false;
+              comment.parsed_text = res.parsed_text;
+              comment.original_text = res.original_text;
+            }
+            return comment;
+          }),
+        );
+      })
+      .catch((err) => {
+        if (err.isError) {
+          const captchaErr = editCaptcha?.handleCaptchaError(err.list);
+          // If it is not a CAPTCHA error, leave it to the subsequent error handling logic to continue processing.
+          if (!(captchaErr && err.list.length === 1)) {
+            return Promise.reject(err);
+          }
+        }
+        return Promise.resolve();
+      });
+  };
+
+  const submitAddComment = (params, item) => {
+    const req = {
+      ...params,
+      captcha_code: undefined,
+      captcha_id: undefined,
+    };
+    addCaptcha?.resolveCaptchaReq(req);
+
+    return addComment(req)
+      .then(async (res) => {
+        await addCaptcha?.close();
+        if (item.type === 'reply') {
+          const index = comments.findIndex(
+            (comment) => comment.comment_id === item.comment_id,
+          );
+          updateCurrentReplyId('');
+          comments.splice(index + 1, 0, res);
+          setComments([...comments]);
+        } else {
+          setComments([
+            ...comments.map((comment) => {
+              if (comment.comment_id === item.comment_id) {
+                updateCurrentReplyId('');
+              }
+              return comment;
+            }),
+            res,
+          ]);
+        }
+
+        setVisibleComment(false);
+      })
+      .catch((ex) => {
+        if (ex.isError) {
+          const captchaErr = addCaptcha?.handleCaptchaError(ex.list);
+          // If it is not a CAPTCHA error, leave it to the subsequent error handling logic to continue processing.
+          if (!(captchaErr && ex.list.length === 1)) {
+            return Promise.reject(ex);
+          }
+        }
+        return Promise.resolve();
+      });
+  };
+
   const handleSendReply = (item) => {
     const users = matchedUsers(item.value);
     const userNames = unionBy(users.map((user) => user.userName));
@@ -153,80 +233,36 @@ const Comment = ({ objectId, mode, commentId }) => {
     };
 
     if (item.type === 'edit') {
-      return editCaptcha.check(() => {
-        const up = {
-          ...params,
-          comment_id: item.comment_id,
-          captcha_code: undefined,
-          captcha_id: undefined,
-        };
-        editCaptcha.resolveCaptchaReq(up);
-
-        return updateComment(up)
-          .then(async (res) => {
-            await editCaptcha.close();
-            setComments(
-              comments.map((comment) => {
-                if (comment.comment_id === item.comment_id) {
-                  comment.showEdit = false;
-                  comment.parsed_text = res.parsed_text;
-                  comment.original_text = res.original_text;
-                }
-                return comment;
-              }),
-            );
-          })
-          .catch((err) => {
-            if (err.isError) {
-              editCaptcha.handleCaptchaError(err.list);
-            }
-          });
-      });
+      if (!editCaptcha) {
+        return submitUpdateComment(params, item);
+      }
+      return editCaptcha.check(() => submitUpdateComment(params, item));
     }
 
-    return addCaptcha.check(() => {
-      const req = {
-        ...params,
-        captcha_code: undefined,
-        captcha_id: undefined,
-      };
-      addCaptcha.resolveCaptchaReq(req);
+    if (!addCaptcha) {
+      return submitAddComment(params, item);
+    }
 
-      return addComment(req)
-        .then(async (res) => {
-          await addCaptcha.close();
-          if (item.type === 'reply') {
-            const index = comments.findIndex(
-              (comment) => comment.comment_id === item.comment_id,
-            );
-            updateCurrentReplyId('');
-            comments.splice(index + 1, 0, res);
-            setComments([...comments]);
-          } else {
-            setComments([
-              ...comments.map((comment) => {
-                if (comment.comment_id === item.comment_id) {
-                  updateCurrentReplyId('');
-                }
-                return comment;
-              }),
-              res,
-            ]);
-          }
+    return addCaptcha.check(() => submitAddComment(params, item));
+  };
 
-          setVisibleComment(false);
-        })
-        .catch((ex) => {
-          if (ex.isError) {
-            const captchaErr = addCaptcha.handleCaptchaError(ex.list);
-            // If it is not a CAPTCHA error, leave it to the subsequent error handling logic to continue processing.
-            if (!(captchaErr && ex.list.length === 1)) {
-              return Promise.reject(ex);
-            }
-          }
-          return Promise.resolve();
-        });
-    });
+  const submitDeleteComment = (id) => {
+    const imgCode = { captcha_id: undefined, captcha_code: undefined };
+    dCaptcha?.resolveCaptchaReq(imgCode);
+
+    deleteComment(id, imgCode)
+      .then(async () => {
+        await dCaptcha?.close();
+        if (pageIndex === 0) {
+          mutate();
+        }
+        setComments(comments.filter((item) => item.comment_id !== id));
+      })
+      .catch((ex) => {
+        if (ex.isError) {
+          dCaptcha?.handleCaptchaError(ex.list);
+        }
+      });
   };
 
   const handleDelete = (id) => {
@@ -236,67 +272,64 @@ const Comment = ({ objectId, mode, commentId }) => {
       confirmBtnVariant: 'danger',
       confirmText: t('delete', { keyPrefix: 'btns' }),
       onConfirm: () => {
+        if (!dCaptcha) {
+          submitDeleteComment(id);
+          return;
+        }
         dCaptcha.check(() => {
-          const imgCode = { captcha_id: undefined, captcha_code: undefined };
-          dCaptcha.resolveCaptchaReq(imgCode);
-
-          deleteComment(id, imgCode)
-            .then(async () => {
-              await dCaptcha.close();
-              if (pageIndex === 0) {
-                mutate();
-              }
-              setComments(comments.filter((item) => item.comment_id !== id));
-            })
-            .catch((ex) => {
-              if (ex.isError) {
-                dCaptcha.handleCaptchaError(ex.list);
-              }
-            });
+          submitDeleteComment(id);
         });
       },
     });
   };
 
+  const submitVoteComment = (id, is_cancel) => {
+    const imgCode: Types.ImgCodeReq = {
+      captcha_id: undefined,
+      captcha_code: undefined,
+    };
+    vCaptcha?.resolveCaptchaReq(imgCode);
+
+    postVote(
+      {
+        object_id: id,
+        is_cancel,
+        ...imgCode,
+      },
+      'up',
+    )
+      .then(async () => {
+        await vCaptcha?.close();
+        setComments(
+          comments.map((item) => {
+            if (item.comment_id === id) {
+              item.vote_count = is_cancel
+                ? item.vote_count - 1
+                : item.vote_count + 1;
+              item.is_vote = !is_cancel;
+            }
+            return item;
+          }),
+        );
+      })
+      .catch((ex) => {
+        if (ex.isError) {
+          vCaptcha?.handleCaptchaError(ex.list);
+        }
+      });
+  };
   const handleVote = (id, is_cancel) => {
     if (!tryNormalLogged(true)) {
       return;
     }
 
-    vCaptcha.check(() => {
-      const imgCode: Types.ImgCodeReq = {
-        captcha_id: undefined,
-        captcha_code: undefined,
-      };
-      vCaptcha.resolveCaptchaReq(imgCode);
+    if (!vCaptcha) {
+      submitVoteComment(id, is_cancel);
+      return;
+    }
 
-      postVote(
-        {
-          object_id: id,
-          is_cancel,
-          ...imgCode,
-        },
-        'up',
-      )
-        .then(async () => {
-          await vCaptcha.close();
-          setComments(
-            comments.map((item) => {
-              if (item.comment_id === id) {
-                item.vote_count = is_cancel
-                  ? item.vote_count - 1
-                  : item.vote_count + 1;
-                item.is_vote = !is_cancel;
-              }
-              return item;
-            }),
-          );
-        })
-        .catch((ex) => {
-          if (ex.isError) {
-            vCaptcha.handleCaptchaError(ex.list);
-          }
-        });
+    vCaptcha.check(() => {
+      submitVoteComment(id, is_cancel);
     });
   };
 
