@@ -28,8 +28,8 @@ const Italic = () => {
   const { t } = useTranslation('translation', { keyPrefix: 'editor' });
   const item = {
     label: 'italic',
-    keyMap: ['Ctrl-I'],
-    tip: `${t('italic.text')} (Ctrl+I)`,
+    keyMap: ['Ctrl-i'],
+    tip: `${t('italic.text')} (Ctrl+i)`,
   };
   const DEFAULTTEXT = t('italic.text');
 
