@@ -29,6 +29,7 @@ import { useTranslation } from 'react-i18next';
 import isEmpty from 'lodash/isEmpty';
 import classnames from 'classnames';
 
+import { scrollToElementTop } from '@/utils';
 import type * as Type from '@/common/interface';
 
 import type {
@@ -201,6 +202,7 @@ const SchemaForm: ForwardRefRenderFunction<FormRef, FormProps> = (
       if (onChange instanceof Function) {
         onChange({ ...formData });
       }
+      scrollToElementTop(document.getElementById(errors[0]));
       return false;
     }
     const syncErrors = await syncValidator();
@@ -216,6 +218,7 @@ const SchemaForm: ForwardRefRenderFunction<FormRef, FormProps> = (
       if (onChange instanceof Function) {
         onChange({ ...formData });
       }
+      scrollToElementTop(document.getElementById(syncErrors[0].key));
       return false;
     }
     return true;
