@@ -27,7 +27,7 @@ import classNames from 'classnames';
 import isEqual from 'lodash/isEqual';
 import debounce from 'lodash/debounce';
 
-import { usePageTags, usePromptWithUnload, useCaptchaModal } from '@/hooks';
+import { usePageTags, usePromptWithUnload } from '@/hooks';
 import { Editor, EditorRef, TagSelector } from '@/components';
 import type * as Type from '@/common/interface';
 import { DRAFT_QUESTION_STORAGE_KEY } from '@/common/constants';
@@ -40,8 +40,14 @@ import {
   getTagsBySlugName,
   saveQuestionWithAnswer,
 } from '@/services';
-import { handleFormError, SaveDraft, storageExpires } from '@/utils';
+import {
+  handleFormError,
+  SaveDraft,
+  storageExpires,
+  scrollToElementTop,
+} from '@/utils';
 import { pathFactory } from '@/router/pathFactory';
+import { useCaptchaPlugin } from '@/utils/pluginKit';
 
 import SearchQuestion from './components/SearchQuestion';
 
@@ -87,7 +93,7 @@ const Ask = () => {
   const [formData, setFormData] = useState<FormDataItem>(initFormData);
   const [immData, setImmData] = useState<FormDataItem>(initFormData);
   const [checked, setCheckState] = useState(false);
-  const contentChangedRef = useRef(false);
+  const [blockState, setBlockState] = useState(false);
   const [focusType, setForceType] = useState('');
   const [hasDraft, setHasDraft] = useState(false);
   const resetForm = () => {
@@ -120,8 +126,8 @@ const Ask = () => {
 
   const isEdit = qid !== undefined;
 
-  const saveCaptcha = useCaptchaModal('question');
-  const editCaptcha = useCaptchaModal('edit');
+  const saveCaptcha = useCaptchaPlugin('question');
+  const editCaptcha = useCaptchaPlugin('edit');
 
   const removeDraft = () => {
     saveDraft.save.cancel();
@@ -165,9 +171,9 @@ const Ask = () => {
           tags.value.map((v) => v.slug_name),
         )
       ) {
-        contentChangedRef.current = true;
+        setBlockState(true);
       } else {
-        contentChangedRef.current = false;
+        setBlockState(false);
       }
       return;
     }
@@ -188,15 +194,15 @@ const Ask = () => {
         },
         callback: () => setHasDraft(true),
       });
-      contentChangedRef.current = true;
+      setBlockState(true);
     } else {
       removeDraft();
-      contentChangedRef.current = false;
+      setBlockState(false);
     }
   }, [formData]);
 
   usePromptWithUnload({
-    when: contentChangedRef.current,
+    when: blockState,
   });
 
   const { data: revisions = [] } = useQueryRevisions(qid);
@@ -276,6 +282,85 @@ const Ask = () => {
     }
   };
 
+  const submitModifyQuestion = (params) => {
+    setBlockState(false);
+    const ep = {
+      ...params,
+      id: qid,
+      edit_summary: formData.edit_summary.value,
+    };
+    const imgCode = editCaptcha?.getCaptcha();
+    if (imgCode?.verify) {
+      ep.captcha_code = imgCode.captcha_code;
+      ep.captcha_id = imgCode.captcha_id;
+    }
+    modifyQuestion(ep)
+      .then(async (res) => {
+        await editCaptcha?.close();
+        navigate(pathFactory.questionLanding(qid, res?.url_title), {
+          state: { isReview: res?.wait_for_review },
+        });
+      })
+      .catch((err) => {
+        if (err.isError) {
+          editCaptcha?.handleCaptchaError(err.list);
+          const data = handleFormError(err, formData);
+          setFormData({ ...data });
+          const ele = document.getElementById(err.list[0].error_field);
+          scrollToElementTop(ele);
+        }
+      });
+  };
+
+  const submitQuestion = async (params) => {
+    setBlockState(false);
+    const imgCode = saveCaptcha?.getCaptcha();
+    if (imgCode?.verify) {
+      params.captcha_code = imgCode.captcha_code;
+      params.captcha_id = imgCode.captcha_id;
+    }
+    let res;
+    if (checked) {
+      res = await saveQuestionWithAnswer({
+        ...params,
+        answer_content: formData.answer_content.value,
+      }).catch((err) => {
+        if (err.isError) {
+          const captchaErr = saveCaptcha?.handleCaptchaError(err.list);
+          if (!(captchaErr && err.list.length === 1)) {
+            const data = handleFormError(err, formData);
+            setFormData({ ...data });
+            const ele = document.getElementById(err.list[0].error_field);
+            scrollToElementTop(ele);
+          }
+        }
+      });
+    } else {
+      res = await saveQuestion(params).catch((err) => {
+        if (err.isError) {
+          const captchaErr = saveCaptcha?.handleCaptchaError(err.list);
+          if (!(captchaErr && err.list.length === 1)) {
+            const data = handleFormError(err, formData);
+            setFormData({ ...data });
+            const ele = document.getElementById(err.list[0].error_field);
+            scrollToElementTop(ele);
+          }
+        }
+      });
+    }
+
+    const id = res?.id || res?.question?.id;
+    if (id) {
+      await saveCaptcha?.close();
+      if (checked) {
+        navigate(pathFactory.questionLanding(id, res?.question?.url_title));
+      } else {
+        navigate(pathFactory.questionLanding(id, res?.url_title));
+      }
+    }
+    removeDraft();
+  };
+
   const handleSubmit = async (event: React.FormEvent<HTMLFormElement>) => {
     event.preventDefault();
     event.stopPropagation();
@@ -287,77 +372,18 @@ const Ask = () => {
     };
 
     if (isEdit) {
-      editCaptcha.check(() => {
-        contentChangedRef.current = false;
-        const ep = {
-          ...params,
-          id: qid,
-          edit_summary: formData.edit_summary.value,
-        };
-        const imgCode = editCaptcha.getCaptcha();
-        if (imgCode.verify) {
-          ep.captcha_code = imgCode.captcha_code;
-          ep.captcha_id = imgCode.captcha_id;
-        }
-        modifyQuestion(ep)
-          .then(async (res) => {
-            await editCaptcha.close();
-            navigate(pathFactory.questionLanding(qid, res?.url_title), {
-              state: { isReview: res?.wait_for_review },
-            });
-          })
-          .catch((err) => {
-            if (err.isError) {
-              editCaptcha.handleCaptchaError(err.list);
-              const data = handleFormError(err, formData);
-              setFormData({ ...data });
-            }
-          });
-      });
+      if (!editCaptcha) {
+        submitModifyQuestion(params);
+        return;
+      }
+      editCaptcha.check(() => submitModifyQuestion(params));
     } else {
-      saveCaptcha.check(async () => {
-        contentChangedRef.current = false;
-        const imgCode = saveCaptcha.getCaptcha();
-        if (imgCode.verify) {
-          params.captcha_code = imgCode.captcha_code;
-          params.captcha_id = imgCode.captcha_id;
-        }
-        let res;
-        if (checked) {
-          res = await saveQuestionWithAnswer({
-            ...params,
-            answer_content: formData.answer_content.value,
-          }).catch((err) => {
-            if (err.isError) {
-              const captchaErr = saveCaptcha.handleCaptchaError(err.list);
-              if (!(captchaErr && err.list.length === 1)) {
-                const data = handleFormError(err, formData);
-                setFormData({ ...data });
-              }
-            }
-          });
-        } else {
-          res = await saveQuestion(params).catch((err) => {
-            if (err.isError) {
-              const captchaErr = saveCaptcha.handleCaptchaError(err.list);
-              if (!(captchaErr && err.list.length === 1)) {
-                const data = handleFormError(err, formData);
-                setFormData({ ...data });
-              }
-            }
-          });
-        }
-
-        const id = res?.id || res?.question?.id;
-        if (id) {
-          await saveCaptcha.close();
-          if (checked) {
-            navigate(pathFactory.questionLanding(id, res?.question?.url_title));
-          } else {
-            navigate(pathFactory.questionLanding(id, res?.url_title));
-          }
-        }
-        removeDraft();
+      if (!saveCaptcha) {
+        submitQuestion(params);
+        return;
+      }
+      saveCaptcha?.check(async () => {
+        submitQuestion(params);
       });
     }
   };
@@ -426,7 +452,7 @@ const Ask = () => {
               </Form.Control.Feedback>
               {bool && <SearchQuestion similarQuestions={similarQuestions} />}
             </Form.Group>
-            <Form.Group controlId="body">
+            <Form.Group controlId="content">
               <Form.Label>{t('form.fields.body.label')}</Form.Label>
               <Form.Control
                 defaultValue={formData.content.value}
